C--------------------------------------------------------------------
C The user of the OPEN-ADAS system and data (hereinafter "the User")
C accepts the following terms and conditions: 
C 
C   1. The University of Strathclyde uses all reasonable endeavours
C      to ensure the accuracy of the data provided and any
C      information given, but the University makes no warranty,
C      expressed or implied as to its accuracy, integrity, fitness
C      for purpose and shall not be responsible for the use to
C      which the data is put by the User and/or any consequences
C      arising out of any inaccuracies or omissions.
C 
C   2. Any downloaded OPEN-ADAS file is made available here for the
C      personal use of the User only.  It must not be used for any
C      commercial application, incorporated into any web site or in
C      any form re-distributed without express prior written
C      permission from the ADAS Project. In particular, but not by
C      way of limitation, it must not be:
C 
C        * inserted into a managed database structure
C        * redistributed along with a modelling or analysis code
C        * made available on a public website.
C 
C Permission for OPEN-ADAS data incorporation in non-commercial
C code/system development for scientific advance will not be
C unreasonably withheld, but will be subject to written agreement
C on a case by case basis.
C 
C The User will indemnify the University of Strathclyde and keep
C it fully and effectively indemnified against each and every
C claim made against the University as a result of the User's
C use of the data.  
C--------------------------------------------------------------------
       PROGRAM TEST
       
       IMPLICIT NONE
C------------------------------------------------------------------------
C  Purpose:
C          Test the XXDATA_09 routine and also provide a brief
C          example of its use.
C
C  Explanaton:
C          This program is distributed as part of the ADAS
C          subroutine library either via direct CVS to ADAS Project
C          members or via download by OPEN-ADAS users. It reads a
C          file called "test.dat" (distributed along with this
C          program) and prints out some of the contents. The
C          program is intended to serve as an example of using the
C          XXDATA_09 subroutine as well as testing it. A short
C          shell script called "test.sh" is used to compile and
C          test the code.
C
C  Variables:
C          All I/O variables are documented by XXDATA_09. See either
C          the Fortran source or the PDF documentation for the routine.
C          Variables not passed into XXDATA_09 are trivial in nature.
C
C  Routines:
C          Routine    Source    Brief description
C          -------------------------------------------------------------
C          XXDATA_09  ADAS      Read complete data from an ADF09 file
C
C  Author : Allan Whiteford
C
C  Date   : 11/01/08
C       
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Parameters required by XXDATA_09
C     --------------------------------        
      INTEGER   NDPRT    , NDREP      , NDLEV      , NDAUG     , NDT
      PARAMETER (NDPRT=5 , NDREP = 50 , NDLEV = 100, NDAUG = 10, NDT=20)
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Input variables (i.e. non-parameter) required by xxdata_09
C     ----------------------------------------------------------
      INTEGER       IUNIT
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Output variables required by xxdata_09
C     --------------------------------------
      CHARACTER*10  CAPRS(NDAUG)
      CHARACTER*18  CSTRGA(NDLEV),             CSTRPA(NDPRT)
      CHARACTER*2   SEQSYM
      CHARACTER*5   TPRTF(NDPRT,NDPRT),        TPRTI(NDPRT)
      INTEGER       IA(NDLEV),    IAPRS,       IL
      INTEGER       ILA(NDLEV), ILPA(NDPRT), IPA(NDPRT)
      INTEGER       IPAUG(NDAUG,2),            IPRTF(NDPRT,NDPRT)
      INTEGER       IPRTI(NDPRT),              IREPA(NDREP)
      INTEGER       ISA(NDLEV), ISPA(NDPRT), ISPRTF(NDPRT,NDPRT)
      INTEGER       ISPRTI(NDPRT)
      INTEGER       ISPSYS(NDPRT,NDPRT,2),     ISYS(NDPRT,NDPRT,2)
      INTEGER       IZ,          IZ0,          IZ1
      INTEGER       NPRNT,       NPRNTF,       NPRNTI
      INTEGER       NREP,        NREPA(NDREP)
      INTEGER       NSYSF(NDPRT,NDPRT),        NTE
      LOGICAL       LAUGA(NDREP,NDAUG)
      LOGICAL       LDIELN(NDREP,NDPRT,NDPRT,2)
      LOGICAL       LDIELR(NDLEV,NDPRT)
      REAL*8        AATP(NDLEV,NDPRT),         AUGA(NDREP,NDAUG)
      REAL*8        BWNP,        BWNR
      REAL*8        DIELN(NDREP,NDPRT,NDPRT,2,NDT)
      REAL*8        DIELR(NDLEV,NDPRT,NDT)
      REAL*8        DIELT(NDPRT,NDPRT,2,NDT), DTOT(NDPRT,NDT)
      REAL*8        TEA(NDT),    WA(NDLEV),    WPA(NDPRT)
      REAL*8        XJA(NDLEV), XJPA(NDPRT)
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Variables only used by this test program
C     ----------------------------------------
      CHARACTER*80 DSNIN
      INTEGER I  
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Open input file for reading
C     ---------------------------
      IUNIT = 10
      DSNIN='test.dat'
      OPEN(UNIT = IUNIT , FILE=DSNIN , STATUS = 'OLD')
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Pass unit number and dimension parameters to XXDATA_01 and
C     get back contents of file.
C     --------------------------

      CALL XXDATA_09( IUNIT  , NDPRT  , NDREP , NDLEV ,
     &                NDAUG  , NDT   ,
     &                SEQSYM , IZ     , IZ0   , IZ1   ,
     &                NPRNT  , NPRNTI , NPRNTF, BWNP  ,
     &                IPA    , CSTRPA , ISPA  , ILPA  , XJPA  ,
     &                WPA    ,
     &                IL     , BWNR   ,
     &                IA     , CSTRGA , ISA   , ILA   , XJA   ,
     &                WA     ,
     &                NREP   , IAPRS  , CAPRS , IPAUG ,
     &                IREPA  , NREPA  , AUGA  , LAUGA ,
     &                IPRTI  , TPRTI  , ISPRTI, DIELR , LDIELR,
     &                IPRTF  , TPRTF  , ISPRTF,
     &                NSYSF  , ISYS   , ISPSYS, DIELN , LDIELN,
     &                DIELT  ,
     &                NTE    , TEA    , AATP ,  DTOT
     &              )
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Print out some of the contents to screen
C     ----------------------------------------

      PRINT *,'XXDATA_09 Test Program'      
      PRINT *,'----------------------'
      PRINT *,' '
      PRINT *,'The following is some information about the'
      PRINT *,'input file: '//DSNIN
      PRINT *,' '       
      PRINT *,'IZ=',IZ,' IZ1=',IZ1,' IZ0=',IZ0
      PRINT *,'----------------------'
      PRINT *,'Recombined levels'
      DO 10 I=1,IL
10	PRINT '(I3,1X,A18,"(",I1,")",I1,"("F4.1,")",2X,F14.1)',I,CSTRGA(I),ISA(I),ILA(I),XJA(I),WA(I)
      PRINT *,'-------------------------------'
      PRINT *,'Temperature grid'
      PRINT *,(TEA(I),I=1,NTE)
      PRINT *,'-------------------------------'
      PRINT *,'Representative N'
      PRINT *,(NREPA(i),i=1,NREP)
      PRINT *,'-------------------------------'

C-----------------------------------------------------------------------
        
        end
